@@ -17,7 +17,7 @@ end
 class StubbedProcessor < Processor
   def process(statements)
     statements.each_with_index do |stmt, index|
-      find_handlers(stmt).each do |handler| 
+      find_handlers(stmt).each do |handler|
         handler.new(self, stmt).process
       end
     end
@@ -27,8 +27,7 @@ end
 class StubbedSourceParser < Parser::SourceParser
   StubbedSourceParser.parser_type = :ruby
   def post_process
-    post = StubbedProcessor.new(@file, @load_order_errors, @parser_type, @globals)
+    post = StubbedProcessor.new(self)
     post.process(@parser.enumerator)
   end
 end
-  
\ No newline at end of file
